#ifndef DAMMIT_H
#define DAMMIT_H

#include <linux/ioctl.h>

#define DAMMIT_MAJOR 253
#define DAMMIT_NAME "dammit"

/* ioctl definitions. */

/*
 * These two define an 8 bit bitmask to use as masks with 8 bit dammit. Bits set in the ON mask will always be on,
 * regardless of the data sent in (OR'd), bits set in the OFF mask will never light. These can be used for special
 * effects outside of the normal pattern, etc.
*/
#define DAMMIT_SET_ON_MASK 	_IOR(DAMMIT_MAJOR, 0, unsigned char)
#define DAMMIT_SET_OFF_MASK 	_IOR(DAMMIT_MAJOR, 1, unsigned char)

/* These two retrieve the values set with the above ioctls. */
#define DAMMIT_GET_ON_MASK 	_IOW(DAMMIT_MAJOR, 2, NULL )
#define DAMMIT_GET_OFF_MASK 	_IOW(DAMMIT_MAJOR, 3, NULL )

/* 
 * This defines how many boxes are active when using the multiplexed driver on minor 2. It is by default 1. Will
 * return -EINVAL if you attempt to call it on a minor other than 2, or the value is not in the range 1-8.
 */
#define DAMMIT_SET_MULTI	_IOR(DAMMIT_MAJOR, 4, unsigned int)

/* Device Minor numbers */
#define DAMMIT_8	0x00
#define DAMMIT_12	0x01
#define DAMMIT_MULTI	0x02

#endif
